==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/os/gos44.h <==
/****************************************************************************

  module      : gos44.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: logging ...
  description : description ...


  last changed: 1999-04-19  13:10
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS44_H
#define GOS44_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp01.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

// --- VOS44C.C --------------------------------------------------------------

externC tsp00_Longint        
sql44c_get_dev_type_by_filename ( char                *pszName );

externC tsp00_Bool        
sql44c_subst_log_parts          ( char                *pszOutName,
                                  char                *pszInName );

externC tsp00_Longint     
sql44c_get_file_info            ( char                *pszFName,
                                  tsp00_Longint       *plAtt,
                                  tsp00_Longuint      *pFSizeLow,
                                  tsp00_Longuint      *pFSizeHigh);

externC bool     
os44Filecopy                   (  char                 *pszSrcName,
                                  char                 *pszDestName,
                                  tsp01_RteError       *RteError ) ;

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS44_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/os/gos44.h <==
/****************************************************************************

  module      : gos44.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: logging ...
  description : description ...


  last changed: 1999-04-19  13:10
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS44_H
#define GOS44_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp01.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

// --- VOS44C.C --------------------------------------------------------------

externC tsp00_Int        
sql44c_get_dev_type_by_filename ( char                 *pszName );

externC tsp00_Bool        
sql44c_subst_log_parts          ( char                 *pszOutName,
                                  char                 *pszInName );

externC tsp00_Int     
sql44c_get_file_info            ( char                 *pszFName,
                                  tsp00_Int            *plAtt,
                                  tsp00_Uint           *pFSizeLow,
                                  tsp00_Uint           *pFSizeHigh);

externC bool     
os44Filecopy                   (  char                 *pszSrcName,
                                  char                 *pszDestName,
                                  tsp01_RteError       *RteError ) ;

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS44_H */
